@@ -56,6 +56,37 @@ def InputValue(storage, parameter):
         input = False
         return input
 
+def FileValue(storage, parameter):
+    try:
+        msgBody = json.loads(parameter)["requestBody"]
+    except:
+        msgBody = parameter
+
+    try:
+        msgOption = msgBody
+        input = msgOption['process']['inputs']['input'][0]['input'][0]['value']
+        file = str(input) + ".gpkg"
+        return file
+    except Exception as e:
+        print(e)
+        file = False
+        return file
+
+def FormatValue(storage, parameter):
+    try:
+        msgBody = json.loads(parameter)["requestBody"]
+    except:
+        msgBody = parameter
+    
+    try:
+        msgOption = msgBody
+        format = msgOption['process']['inputs']['input'][0]['input'][0]['format']
+        return format
+    except Exception as e:
+        print(e)
+        format = False
+        return format
+
 
 def ParamValue(storage, parameter):
     try:
@@ -387,4 +418,4 @@ def ProcessFail(storage, parameter, msg):
     }
 
     print("process failed")
-    return json.dumps(out_msg)
\ No newline at end of file
+    return json.dumps(out_msg)
